#define MU_GIT_COMMIT_HASH "b6254c496de66346cd4e7c5a9ced188d86adee2a"
#define MU_GIT_COMMIT_TIME "2025-12-11 15:11:59 +0200"
#define MU_GIT_COMMIT_SUBJECT "Version 3.21"
#define MU_GIT_DESCRIBE_STRING "v3.20-45-gb6254c496"
